import * as render from "./render";
import Hist from "redoundo";
/** Interface of a parental `Actions` */
export interface IActionsParent {
    /** renderer that should be called for page re-rendering */
    readonly Renderer: render.IRenderer;
    /** `redoundo.Hist` object for redo/undo functionality */
    readonly History: Hist;
}
/** Class of hyperoop top-level action */
export declare class Actions<S extends {}> {
    /** state object */
    readonly State: S;
    /** state object that remember previous states and has redo/undo functionality */
    readonly Remember: S;
    /** renderer that should be called for page re-rendering */
    readonly Renderer: render.IRenderer;
    /** `redoundo.Hist` object implements redo/undo functionality */
    readonly History: Hist;
    private orig;
    private state;
    private remember;
    private renderer;
    /** Construct an `Actions` object
     *
     * @param start state on start
     * @param hist `redoundo.Hist` object implements redo/undo functionality
     */
    constructor(start: S, hist?: number | Hist);
    /** Partially sets a new state
     *
     * @param s new state data
     * @param remember remember previous state using `redoundo.Hist` or not?
     */
    set(s: Partial<S>, remember?: boolean): void;
    /** Initialize `Actions` with new renderer
     *
     * @param r
     */
    init(r: render.IRenderer): void;
}
/** Class of hyperoop sub-actions */
export declare class SubActions<S extends {}> extends Actions<S> {
    /** Constructs `SubActions` object inheriting `History` and `Renderer` from a parent.
     *  NOTE! If `SubActions` object created before first rendering then you will need
     *  to call it's `init` manually.
     *
     * @param start state on start
     * @param parent parent `(Sub)Actions` object.
     */
    constructor(start: S, parent: IActionsParent);
}
