/** The VDOM representation of an HTMLElement. */
export interface IVirtualNode<A = {}> {
    nodeName: string;
    attributes?: A;
    children: ChildVirtualNode[];
    key?: string;
}
/** A ImmediateComponent is a function that returns a custom VNode. */
export declare type PlainComponent<A = {}> = (attributes: A, children: ChildVirtualNode[]) => IVirtualNode<A>;
/** A LazyComponent is a function that returns a custom LazyVNode. */
export declare type LazyComponent<A = {}> = (attributes: A, children: ChildVirtualNode[]) => LazyVirtualNode;
/** A Component can be lazy or immediate. */
export declare type Component<A = {}> = LazyComponent<A> | PlainComponent<A>;
/** Possible types of child nodes */
export declare type ChildVirtualNode<A = {}> = IVirtualNode<A> | string | number | null;
/** The view function describes the application UI as a tree of VNodes.
 * @returns A VNode tree.
 */
export declare type LazyVirtualNode = () => IVirtualNode<object>;
declare type ChildLike = ChildVirtualNode | ChildVirtualNode[];
export declare function h<A>(name: string | PlainComponent<A>, attributes?: A, ...rest: ChildLike[]): IVirtualNode<A>;
export declare function h<A>(comp: LazyComponent<A>, attributes?: A, ...rest: ChildLike[]): LazyVirtualNode;
export declare type JSXFactory = typeof h;
export {};
